@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use 5.004;
 
-$VERSION = "0.17008"; 
+$VERSION = "0.17011"; 
 
 use overload (
 	'""'	   =>	'stringify',
@@ -140,11 +140,6 @@ sub associate {
     return;
 }
 
-=head2 Error->new()
-
-See the Error::Simple documentation.
-
-=cut
 
 sub new {
     my $self = shift;
@@ -264,12 +259,6 @@ package Error::Simple;
 
 @Error::Simple::ISA = qw(Error);
 
-=head2 Error->new()
-
-See the Error::Simple documentation.
-
-=cut
-
 sub new {
     my $self  = shift;
     my $text  = "" . shift;
@@ -356,8 +345,7 @@ sub run_clauses ($$$\@) {
 			    undef $err;
 			}
 			else {
-			    $err = defined($Error::THROWN)
-				    ? $Error::THROWN : $@;
+			    $err = $@ || $Error::THROWN;
 				$err = $Error::ObjectifyCallback->({'text' =>$err})
 					unless ref($err);
 			}
@@ -391,8 +379,7 @@ sub run_clauses ($$$\@) {
 		undef $err;
 	    }
 	    else {
-		$err = defined($Error::THROWN)
-			? $Error::THROWN : $@;
+		$err = $@ || $Error::THROWN;
 
 		$err = $Error::ObjectifyCallback->({'text' =>$err}) 
 			unless ref($err);
@@ -430,7 +417,7 @@ sub try (&;$) {
 	    1;
 	};
 
-	$err = defined($Error::THROWN) ? $Error::THROWN : $@
+	$err = $@ || $Error::THROWN
 	    unless $ok;
     };
 
@@ -769,6 +756,10 @@ an object blessed into that package as the C<-object> argument.
 
 =over 4
 
+=item Error->new()
+
+See the Error::Simple documentation.
+
 =item throw ( [ ARGS ] )
 
 Create a new C<Error> object and throw an error, which will be caught
